Welcome to rancidcmd’s documentation! — rancidcmd 0.1.5 documentation

# Welcome to rancidcmd’s documentation!

Contents:

RancidCmd.

class `rancidcmd.` `RancidCmd`(**kwargs)

  The `RancidCmd` object.

  RancidCmd

  static `check_cloginrc`(name='.cloginrc')

    Check rancid settings file (default: .cloginrc).

  `cmd_exec`(command)

    Login and command execution.

  `cmd_token`(command)

    Split one line command.

  `decode_bytes`(byte_data)

    Change string with encoding setting.

  `execute`(command)

    Command execution.

  `generate_cmd`(command)

    Make login command.

  static `touch`(path)

    Make empty file.

# Indices and tables

- Index
- Module Index
- Search Page